@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 """Top-level package for ce-detector."""
 
-__author__ = """YangyangLi"""
+__author__ = "YangyangLi"
 __email__ = "li002252@umn.edu "
-__version__ = "__version__ = '0.1.8'"
+__version__ = "0.1.13"
 
 # from .annotator import Annotator
 # from .ce_scanner import Scanner
